import { aws_codepipeline as cpipeline } from 'aws-cdk-lib';
import { Construct } from 'constructs';
export interface ChimeNotifierOptions {
    /**
     * Chime webhook URLs to send to
     */
    readonly webhookUrls: string[];
    /**
     * The message to send to the channels.
     *
     * Can use the following placeholders:
     *
     * - $PIPELINE: the name of the pipeline
     * - $REVISION: description of the failing revision
     * - $ACTION: name of failing action
     * - $URL: link to failing action details
     *
     * @default - A default message
     */
    readonly message?: string;
}
/**
 * Properties for a ChimeNotifier
 */
export interface ChimeNotifierProps extends ChimeNotifierOptions {
    /**
     * Code Pipeline to listen to
     */
    readonly pipeline: cpipeline.IPipeline;
}
/**
 * Send a message to a Chime room when a pipeline fails
 */
export declare class ChimeNotifier extends Construct {
    constructor(scope: Construct, id: string, props: ChimeNotifierProps);
}
