import { aws_chatbot as chatbot } from 'aws-cdk-lib';
import { IPipelineNotification, PipelineNotificationBindOptions } from '../';
/**
 * Properties to initialize SlackNotification
 */
export interface SlackNotificationProps {
    /**
     * The list of Chatbot registered slack channels.
     */
    readonly channels: chatbot.SlackChannelConfiguration[];
    /**
     * The level of details to be included in the notification
     * @default SlackNotificationDetailLevel.BASIC
     */
    readonly detailLevel?: SlackNotificationDetailLevel;
}
/**
 * The level of details to be included in a slack notification.
 */
export declare enum SlackNotificationDetailLevel {
    /**
     * Basic event details without the contents of the error message.
     */
    BASIC = "BASIC",
    /**
     * Information included in BASIC, plus the contents of the error message.
     */
    FULL = "FULL"
}
/**
 * Notify events on pipeline to a Slack channel via AWS Chatbot
 */
export declare class SlackNotification implements IPipelineNotification {
    private readonly props;
    constructor(props: SlackNotificationProps);
    bind(options: PipelineNotificationBindOptions): void;
}
