import { aws_iam as iam } from 'aws-cdk-lib';
import { Construct } from 'constructs';
/**
 * Construction properties for a SigningKey
 */
export interface SigningKeyProps {
    /**
     * The AWS Secrets Manager secret name to use for this key.
     *
     * The secret will be named "<scope>/SigningKey".
     *
     * @default A unique secret name will be automatically generated
     */
    secretName?: string;
    /**
     * Name to put on key
     */
    identity: string;
    /**
     * Email address to put on key
     */
    email: string;
}
/**
 * A combination of a Secrets Manager secret and a unique KMS key per secret
 *
 * The KMS key is there to control access to the secret, as the secret
 * itself doesn't support resource policies yet.
 *
 * @deprecated Use the OpenPGPKeyPair class instead.
 */
export declare class OpenPgpKey extends Construct {
    readonly scope: string;
    private readonly key;
    private readonly secret;
    constructor(parent: Construct, name: string, props: SigningKeyProps);
    grantRead(identity: iam.IPrincipal): void;
}
